@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,12 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.cloud.servicecontrol_v1.types import distribution
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.cloud.servicecontrol_v1.types import distribution as gas_distribution
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -29,7 +26,6 @@ __protobuf__ = proto.module(
 
 class MetricValue(proto.Message):
     r"""Represents a single metric value.
-
     Attributes:
         labels (Sequence[google.cloud.servicecontrol_v1.types.MetricValue.LabelsEntry]):
             The labels describing the metric value. See comments on
@@ -37,15 +33,18 @@ class MetricValue(proto.Message):
             for the overriding relationship. Note that this map must not
             contain monitored resource labels.
         start_time (google.protobuf.timestamp_pb2.Timestamp):
-            The start of the time period over which this
-            metric value's measurement applies. The time
-            period has different semantics for different
-            metric types (cumulative, delta, and gauge). See
-            the metric definition documentation in the
-            service configuration for details.
+            The start of the time period over which this metric value's
+            measurement applies. The time period has different semantics
+            for different metric types (cumulative, delta, and gauge).
+            See the metric definition documentation in the service
+            configuration for details. If not specified,
+            [google.api.servicecontrol.v1.Operation.start_time][google.api.servicecontrol.v1.Operation.start_time]
+            will be used.
         end_time (google.protobuf.timestamp_pb2.Timestamp):
-            The end of the time period over which this
-            metric value's measurement applies.
+            The end of the time period over which this metric value's
+            measurement applies. If not specified,
+            [google.api.servicecontrol.v1.Operation.end_time][google.api.servicecontrol.v1.Operation.end_time]
+            will be used.
         bool_value (bool):
             A boolean value.
         int64_value (int):
@@ -58,22 +57,15 @@ class MetricValue(proto.Message):
             A distribution value.
     """
 
-    labels = proto.MapField(proto.STRING, proto.STRING, number=1)
-
-    start_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    bool_value = proto.Field(proto.BOOL, number=4, oneof="value")
-
-    int64_value = proto.Field(proto.INT64, number=5, oneof="value")
-
-    double_value = proto.Field(proto.DOUBLE, number=6, oneof="value")
-
-    string_value = proto.Field(proto.STRING, number=7, oneof="value")
-
+    labels = proto.MapField(proto.STRING, proto.STRING, number=1,)
+    start_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    bool_value = proto.Field(proto.BOOL, number=4, oneof="value",)
+    int64_value = proto.Field(proto.INT64, number=5, oneof="value",)
+    double_value = proto.Field(proto.DOUBLE, number=6, oneof="value",)
+    string_value = proto.Field(proto.STRING, number=7, oneof="value",)
     distribution_value = proto.Field(
-        proto.MESSAGE, number=8, oneof="value", message=distribution.Distribution,
+        proto.MESSAGE, number=8, oneof="value", message=gas_distribution.Distribution,
     )
 
 
@@ -90,8 +82,7 @@ class MetricValueSet(proto.Message):
             The values in this metric.
     """
 
-    metric_name = proto.Field(proto.STRING, number=1)
-
+    metric_name = proto.Field(proto.STRING, number=1,)
     metric_values = proto.RepeatedField(proto.MESSAGE, number=2, message="MetricValue",)
 
 
